Protection Profiles : CC Portal

Login

- NEWS
- ICCC
- PROTECTION PROFILES
- COLLABORATIVE PPS
- CERTIFIED PRODUCTS
- TECHNICAL COMMUNITIES
- PUBLICATIONS
- ABOUT THE CC
- HOME

# Protection Profiles

Statistics Download CSV Collaborative Protection Profiles Archived Protection Profiles

Protection Profiles List CSV file generated
Search:
Filter by:
Number of results:

Protection Profile | Version | Assurance Level | Issued | Scheme | Certified | Categories
--- | --- | --- | --- | --- | --- | ---

#### expand/collapse all categories

Protection Profile | Version | Assurance Level | Issued | Scheme | Certified
--- | --- | --- | --- | --- | ---
Access Control Devices and Systems – 7 Protection Profiles
Korean National Protection Profile for Single Sign On V1.0 | V1.0 | EAL1+ ATE_FUN.1 | 2017-08-18 | KR | Certification Report

Protection Profile | Version | Assurance Level | Issued | Scheme | Certified
--- | --- | --- | --- | --- | ---
Biometric Systems and Devices – 6 Protection Profiles
Fingerprint Spoof Detection Protection Profile based on Organisational Security Policies (FSDPP_OSP), Version 1.7 | 1.7 | EAL2+ ALC_FLR.1 | 2010-02-25 | DE | Certification Report

Protection Profile | Version | Assurance Level | Issued | Scheme | Certified
--- | --- | --- | --- | --- | ---
Other Devices and Systems – 81 Protection Profiles
Protection Profile for Security Module of General-Purpose Health Informatics Software | 1.0 | EAL2 | 2016-09-20 | TR | Certification Report